address

# XMLRésuméLibrary: User Guide

achievements | Element Reference | annotation

## Name

address — A postal address

## Synopsis

### Content Model

    (#PCDATA|street|street2|suburb|ward|city|state|province|county|prefecture|zip|postalCode|country|break)*

### Attributes

Name | Type | Default
--- | --- | ---
format | Enumeration:
`standard`
`european`
`italian`
| None
id | ID | None
targets | CDATA | None

## Description

The `address` element defines a single postal address. It does not contain information about a person who resides at the address.

Different countries have different address formatting conventions. Address formatting is controlled by the `address.format` parameter.

If an address cannot be specified using `address`'s child elements (`street`, `city`, etc.), it may be specified in untagged format. In this case, the address will be formatted verbatim, with line breaks preserved.

### Parents

`address` may be contained in these elements: `header`, `referee`

### Attributes

`id`

  A string used to uniquely identify an address. The address may then be referred to by this identifier.

`format`

  The address format. This attribute specifies the format of an address, and overrides the global `address.format` parameter for each address that it appears in.

## See Also

`address.format`.

## Examples

Example 1. U.S.-style address

    <address>
      <street>123 Pickle St.</street>
      <street>Apt. #12</street>
      <city>Sourville</city>
      <state>NX</state>
      <zip>99999-9999</zip>
    </address>

Formatted as:

`123 Pickle St. Apt. #12
Sourville, NX 99999-9999`

Example 2. Italian address

    <address>
      <street>Via Garibaldi, 23</street>
      <city>Sorrento</city>
      <postalCode>123 456</postalCode>
      <province>NA</province>
      <country>Italy</country>
    </address>

Example 3. Untagged address

    <address>Reina #35, apt. 4a, e/ Gervasio y Escobar
    Ciudad de La Habana, CP 11900
    CUBA</address>

Formatted as:

`Reina #35, apt. 4a, e/ Gervasio y Escobar
Ciudad de La Habana, CP 11900
CUBA`

### Warning

You may have noticed that the XML for this address isn't indented as usual. This is because untagged addresses are formatted verbatim, and so any indentation would be preserved in the formatted address. The address text begins on the same line as the start tag for the same reason (we don't want a leading linebreak in the formatted address).

For additional address examples, look at the XML files in the `examples/addressing` directory of the XML Résumé Library distribution.

achievements | Element Reference | annotation